Learn R Programming

photobiologyWavebands (version 0.5.0)

Far_red: Constructor of far-red waveband

Description

Far-red radiation has no standardized definitions. Far-red is important in photobiology of plants mainly in relation to the phytochrome photoreceptors. The definitions proposed by Prof. Harry Smith are the most widely used, specially to compute a red to far-red photon ratio. However, other authors have used different definitions in their publications. These other definitions are preferred in situations where phytochromes are not the target of study. For example the "red edge" is is used in remote sensing to detect the condition of vegetation. plant photobiology, "Smith10" (725-735 nm), "Smith20" (720-740 nm), "Inada" (700-800 nm), "Warrington" (700-850 nm), and "Sellaro" (700-750 nm). The red-edge used in remote sensing of vegetation is centred at the reflectance transition in the far-red band (725 nm), we define "RedEdge40" (705-745 nm) and "RedEdge20" (715-735 nm).

Usage

Far_red(std = "ISO")

Value

An object of class waveband, a class defined in package 'photobiology'.

Arguments

std

a character string, defaults to "ISO", as for other colour definitions, which in this case returns NA.

See Also

NIR for wavebands close to the boundary between red and infrared regions.

waveband

Other unweighted wavebands: Blue(), Green(), IR(), Orange(), Purple(), Red(), UVA(), UVB(), UVC(), UV(), VIS(), Yellow()

Examples

Run this code
Far_red() # no ISO definition exists
Far_red("ISO") # no ISO definition exists
Far_red("Smith10") # 10 nm wide
Far_red("Smith20") # 20 nm wide
Far_red("Inada")
Far_red("Warrington")
Far_red("Sellaro")
Far_red("RedEdge40")
Far_red("RedEdge20")

Run the code above in your browser using DataLab